-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:94
--
-- | This module exports combinators that provide you with the
-- ability to set attributes on HTML elements.
--
{-# LANGUAGE OverloadedStrings #-}
module Text.Blaze.Html4.FrameSet.Attributes
    ( abbr
    , accept
    , accesskey
    , action
    , align
    , alt
    , archive
    , axis
    , background
    , bgcolor
    , border
    , cellpadding
    , cellspacing
    , char
    , charoff
    , charset
    , checked
    , cite
    , class_
    , classid
    , clear
    , codebase
    , codetype
    , cols
    , colspan
    , compact
    , content
    , coords
    , data_
    , datetime
    , declare
    , defer
    , dir
    , disabled
    , enctype
    , for
    , frame
    , frameborder
    , headers
    , height
    , href
    , hreflang
    , hspace
    , httpEquiv
    , id
    , label
    , lang
    , language
    , maxlength
    , media
    , method
    , multiple
    , name
    , nohref
    , noshade
    , nowrap
    , onabort
    , onblur
    , onchange
    , onclick
    , ondblclick
    , onfocus
    , onkeydown
    , onkeypress
    , onkeyup
    , onload
    , onmousedown
    , onmousemove
    , onmouseout
    , onmouseover
    , onmouseup
    , onreset
    , onselect
    , onsubmit
    , onunload
    , profile
    , readonly
    , rel
    , rev
    , rows
    , rowspan
    , rules
    , scheme
    , scope
    , scrolling
    , selected
    , shape
    , size
    , span
    , src
    , standby
    , start
    , style
    , summary
    , tabindex
    , target
    , title
    , type_
    , usemap
    , valign
    , value
    , valuetype
    , vspace
    , width
    ) where

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:100
--
import Prelude ()

import Text.Blaze.Internal (Attribute, AttributeValue, attribute)

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @abbr@ attribute.
--
-- Example:
--
-- > div ! abbr "bar" $ "Hello."
--
-- Result:
--
-- > <div abbr="bar">Hello.</div>
--
abbr :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
abbr = attribute "abbr" " abbr=\""
{-# INLINE abbr #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @accept@ attribute.
--
-- Example:
--
-- > div ! accept "bar" $ "Hello."
--
-- Result:
--
-- > <div accept="bar">Hello.</div>
--
accept :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
accept = attribute "accept" " accept=\""
{-# INLINE accept #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @accesskey@ attribute.
--
-- Example:
--
-- > div ! accesskey "bar" $ "Hello."
--
-- Result:
--
-- > <div accesskey="bar">Hello.</div>
--
accesskey :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
accesskey = attribute "accesskey" " accesskey=\""
{-# INLINE accesskey #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @action@ attribute.
--
-- Example:
--
-- > div ! action "bar" $ "Hello."
--
-- Result:
--
-- > <div action="bar">Hello.</div>
--
action :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
action = attribute "action" " action=\""
{-# INLINE action #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @align@ attribute.
--
-- Example:
--
-- > div ! align "bar" $ "Hello."
--
-- Result:
--
-- > <div align="bar">Hello.</div>
--
align :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
align = attribute "align" " align=\""
{-# INLINE align #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @alt@ attribute.
--
-- Example:
--
-- > div ! alt "bar" $ "Hello."
--
-- Result:
--
-- > <div alt="bar">Hello.</div>
--
alt :: AttributeValue  -- ^ Attribute value.
    -> Attribute       -- ^ Resulting attribute.
alt = attribute "alt" " alt=\""
{-# INLINE alt #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @archive@ attribute.
--
-- Example:
--
-- > div ! archive "bar" $ "Hello."
--
-- Result:
--
-- > <div archive="bar">Hello.</div>
--
archive :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
archive = attribute "archive" " archive=\""
{-# INLINE archive #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @axis@ attribute.
--
-- Example:
--
-- > div ! axis "bar" $ "Hello."
--
-- Result:
--
-- > <div axis="bar">Hello.</div>
--
axis :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
axis = attribute "axis" " axis=\""
{-# INLINE axis #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @background@ attribute.
--
-- Example:
--
-- > div ! background "bar" $ "Hello."
--
-- Result:
--
-- > <div background="bar">Hello.</div>
--
background :: AttributeValue  -- ^ Attribute value.
           -> Attribute       -- ^ Resulting attribute.
background = attribute "background" " background=\""
{-# INLINE background #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @bgcolor@ attribute.
--
-- Example:
--
-- > div ! bgcolor "bar" $ "Hello."
--
-- Result:
--
-- > <div bgcolor="bar">Hello.</div>
--
bgcolor :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
bgcolor = attribute "bgcolor" " bgcolor=\""
{-# INLINE bgcolor #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @border@ attribute.
--
-- Example:
--
-- > div ! border "bar" $ "Hello."
--
-- Result:
--
-- > <div border="bar">Hello.</div>
--
border :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
border = attribute "border" " border=\""
{-# INLINE border #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @cellpadding@ attribute.
--
-- Example:
--
-- > div ! cellpadding "bar" $ "Hello."
--
-- Result:
--
-- > <div cellpadding="bar">Hello.</div>
--
cellpadding :: AttributeValue  -- ^ Attribute value.
            -> Attribute       -- ^ Resulting attribute.
cellpadding = attribute "cellpadding" " cellpadding=\""
{-# INLINE cellpadding #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @cellspacing@ attribute.
--
-- Example:
--
-- > div ! cellspacing "bar" $ "Hello."
--
-- Result:
--
-- > <div cellspacing="bar">Hello.</div>
--
cellspacing :: AttributeValue  -- ^ Attribute value.
            -> Attribute       -- ^ Resulting attribute.
cellspacing = attribute "cellspacing" " cellspacing=\""
{-# INLINE cellspacing #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @char@ attribute.
--
-- Example:
--
-- > div ! char "bar" $ "Hello."
--
-- Result:
--
-- > <div char="bar">Hello.</div>
--
char :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
char = attribute "char" " char=\""
{-# INLINE char #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @charoff@ attribute.
--
-- Example:
--
-- > div ! charoff "bar" $ "Hello."
--
-- Result:
--
-- > <div charoff="bar">Hello.</div>
--
charoff :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
charoff = attribute "charoff" " charoff=\""
{-# INLINE charoff #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @charset@ attribute.
--
-- Example:
--
-- > div ! charset "bar" $ "Hello."
--
-- Result:
--
-- > <div charset="bar">Hello.</div>
--
charset :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
charset = attribute "charset" " charset=\""
{-# INLINE charset #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @checked@ attribute.
--
-- Example:
--
-- > div ! checked "bar" $ "Hello."
--
-- Result:
--
-- > <div checked="bar">Hello.</div>
--
checked :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
checked = attribute "checked" " checked=\""
{-# INLINE checked #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @cite@ attribute.
--
-- Example:
--
-- > div ! cite "bar" $ "Hello."
--
-- Result:
--
-- > <div cite="bar">Hello.</div>
--
cite :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
cite = attribute "cite" " cite=\""
{-# INLINE cite #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @class@ attribute.
--
-- Example:
--
-- > div ! class_ "bar" $ "Hello."
--
-- Result:
--
-- > <div class="bar">Hello.</div>
--
class_ :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
class_ = attribute "class" " class=\""
{-# INLINE class_ #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @classid@ attribute.
--
-- Example:
--
-- > div ! classid "bar" $ "Hello."
--
-- Result:
--
-- > <div classid="bar">Hello.</div>
--
classid :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
classid = attribute "classid" " classid=\""
{-# INLINE classid #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @clear@ attribute.
--
-- Example:
--
-- > div ! clear "bar" $ "Hello."
--
-- Result:
--
-- > <div clear="bar">Hello.</div>
--
clear :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
clear = attribute "clear" " clear=\""
{-# INLINE clear #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @codebase@ attribute.
--
-- Example:
--
-- > div ! codebase "bar" $ "Hello."
--
-- Result:
--
-- > <div codebase="bar">Hello.</div>
--
codebase :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
codebase = attribute "codebase" " codebase=\""
{-# INLINE codebase #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @codetype@ attribute.
--
-- Example:
--
-- > div ! codetype "bar" $ "Hello."
--
-- Result:
--
-- > <div codetype="bar">Hello.</div>
--
codetype :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
codetype = attribute "codetype" " codetype=\""
{-# INLINE codetype #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @cols@ attribute.
--
-- Example:
--
-- > div ! cols "bar" $ "Hello."
--
-- Result:
--
-- > <div cols="bar">Hello.</div>
--
cols :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
cols = attribute "cols" " cols=\""
{-# INLINE cols #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @colspan@ attribute.
--
-- Example:
--
-- > div ! colspan "bar" $ "Hello."
--
-- Result:
--
-- > <div colspan="bar">Hello.</div>
--
colspan :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
colspan = attribute "colspan" " colspan=\""
{-# INLINE colspan #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @compact@ attribute.
--
-- Example:
--
-- > div ! compact "bar" $ "Hello."
--
-- Result:
--
-- > <div compact="bar">Hello.</div>
--
compact :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
compact = attribute "compact" " compact=\""
{-# INLINE compact #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @content@ attribute.
--
-- Example:
--
-- > div ! content "bar" $ "Hello."
--
-- Result:
--
-- > <div content="bar">Hello.</div>
--
content :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
content = attribute "content" " content=\""
{-# INLINE content #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @coords@ attribute.
--
-- Example:
--
-- > div ! coords "bar" $ "Hello."
--
-- Result:
--
-- > <div coords="bar">Hello.</div>
--
coords :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
coords = attribute "coords" " coords=\""
{-# INLINE coords #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @data@ attribute.
--
-- Example:
--
-- > div ! data_ "bar" $ "Hello."
--
-- Result:
--
-- > <div data="bar">Hello.</div>
--
data_ :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
data_ = attribute "data" " data=\""
{-# INLINE data_ #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @datetime@ attribute.
--
-- Example:
--
-- > div ! datetime "bar" $ "Hello."
--
-- Result:
--
-- > <div datetime="bar">Hello.</div>
--
datetime :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
datetime = attribute "datetime" " datetime=\""
{-# INLINE datetime #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @declare@ attribute.
--
-- Example:
--
-- > div ! declare "bar" $ "Hello."
--
-- Result:
--
-- > <div declare="bar">Hello.</div>
--
declare :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
declare = attribute "declare" " declare=\""
{-# INLINE declare #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @defer@ attribute.
--
-- Example:
--
-- > div ! defer "bar" $ "Hello."
--
-- Result:
--
-- > <div defer="bar">Hello.</div>
--
defer :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
defer = attribute "defer" " defer=\""
{-# INLINE defer #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @dir@ attribute.
--
-- Example:
--
-- > div ! dir "bar" $ "Hello."
--
-- Result:
--
-- > <div dir="bar">Hello.</div>
--
dir :: AttributeValue  -- ^ Attribute value.
    -> Attribute       -- ^ Resulting attribute.
dir = attribute "dir" " dir=\""
{-# INLINE dir #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @disabled@ attribute.
--
-- Example:
--
-- > div ! disabled "bar" $ "Hello."
--
-- Result:
--
-- > <div disabled="bar">Hello.</div>
--
disabled :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
disabled = attribute "disabled" " disabled=\""
{-# INLINE disabled #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @enctype@ attribute.
--
-- Example:
--
-- > div ! enctype "bar" $ "Hello."
--
-- Result:
--
-- > <div enctype="bar">Hello.</div>
--
enctype :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
enctype = attribute "enctype" " enctype=\""
{-# INLINE enctype #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @for@ attribute.
--
-- Example:
--
-- > div ! for "bar" $ "Hello."
--
-- Result:
--
-- > <div for="bar">Hello.</div>
--
for :: AttributeValue  -- ^ Attribute value.
    -> Attribute       -- ^ Resulting attribute.
for = attribute "for" " for=\""
{-# INLINE for #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @frame@ attribute.
--
-- Example:
--
-- > div ! frame "bar" $ "Hello."
--
-- Result:
--
-- > <div frame="bar">Hello.</div>
--
frame :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
frame = attribute "frame" " frame=\""
{-# INLINE frame #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @frameborder@ attribute.
--
-- Example:
--
-- > div ! frameborder "bar" $ "Hello."
--
-- Result:
--
-- > <div frameborder="bar">Hello.</div>
--
frameborder :: AttributeValue  -- ^ Attribute value.
            -> Attribute       -- ^ Resulting attribute.
frameborder = attribute "frameborder" " frameborder=\""
{-# INLINE frameborder #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @headers@ attribute.
--
-- Example:
--
-- > div ! headers "bar" $ "Hello."
--
-- Result:
--
-- > <div headers="bar">Hello.</div>
--
headers :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
headers = attribute "headers" " headers=\""
{-# INLINE headers #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @height@ attribute.
--
-- Example:
--
-- > div ! height "bar" $ "Hello."
--
-- Result:
--
-- > <div height="bar">Hello.</div>
--
height :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
height = attribute "height" " height=\""
{-# INLINE height #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @href@ attribute.
--
-- Example:
--
-- > div ! href "bar" $ "Hello."
--
-- Result:
--
-- > <div href="bar">Hello.</div>
--
href :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
href = attribute "href" " href=\""
{-# INLINE href #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @hreflang@ attribute.
--
-- Example:
--
-- > div ! hreflang "bar" $ "Hello."
--
-- Result:
--
-- > <div hreflang="bar">Hello.</div>
--
hreflang :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
hreflang = attribute "hreflang" " hreflang=\""
{-# INLINE hreflang #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @hspace@ attribute.
--
-- Example:
--
-- > div ! hspace "bar" $ "Hello."
--
-- Result:
--
-- > <div hspace="bar">Hello.</div>
--
hspace :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
hspace = attribute "hspace" " hspace=\""
{-# INLINE hspace #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @http-equiv@ attribute.
--
-- Example:
--
-- > div ! httpEquiv "bar" $ "Hello."
--
-- Result:
--
-- > <div http-equiv="bar">Hello.</div>
--
httpEquiv :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
httpEquiv = attribute "http-equiv" " http-equiv=\""
{-# INLINE httpEquiv #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @id@ attribute.
--
-- Example:
--
-- > div ! id "bar" $ "Hello."
--
-- Result:
--
-- > <div id="bar">Hello.</div>
--
id :: AttributeValue  -- ^ Attribute value.
   -> Attribute       -- ^ Resulting attribute.
id = attribute "id" " id=\""
{-# INLINE id #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @label@ attribute.
--
-- Example:
--
-- > div ! label "bar" $ "Hello."
--
-- Result:
--
-- > <div label="bar">Hello.</div>
--
label :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
label = attribute "label" " label=\""
{-# INLINE label #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @lang@ attribute.
--
-- Example:
--
-- > div ! lang "bar" $ "Hello."
--
-- Result:
--
-- > <div lang="bar">Hello.</div>
--
lang :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
lang = attribute "lang" " lang=\""
{-# INLINE lang #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @language@ attribute.
--
-- Example:
--
-- > div ! language "bar" $ "Hello."
--
-- Result:
--
-- > <div language="bar">Hello.</div>
--
language :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
language = attribute "language" " language=\""
{-# INLINE language #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @maxlength@ attribute.
--
-- Example:
--
-- > div ! maxlength "bar" $ "Hello."
--
-- Result:
--
-- > <div maxlength="bar">Hello.</div>
--
maxlength :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
maxlength = attribute "maxlength" " maxlength=\""
{-# INLINE maxlength #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @media@ attribute.
--
-- Example:
--
-- > div ! media "bar" $ "Hello."
--
-- Result:
--
-- > <div media="bar">Hello.</div>
--
media :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
media = attribute "media" " media=\""
{-# INLINE media #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @method@ attribute.
--
-- Example:
--
-- > div ! method "bar" $ "Hello."
--
-- Result:
--
-- > <div method="bar">Hello.</div>
--
method :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
method = attribute "method" " method=\""
{-# INLINE method #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @multiple@ attribute.
--
-- Example:
--
-- > div ! multiple "bar" $ "Hello."
--
-- Result:
--
-- > <div multiple="bar">Hello.</div>
--
multiple :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
multiple = attribute "multiple" " multiple=\""
{-# INLINE multiple #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @name@ attribute.
--
-- Example:
--
-- > div ! name "bar" $ "Hello."
--
-- Result:
--
-- > <div name="bar">Hello.</div>
--
name :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
name = attribute "name" " name=\""
{-# INLINE name #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @nohref@ attribute.
--
-- Example:
--
-- > div ! nohref "bar" $ "Hello."
--
-- Result:
--
-- > <div nohref="bar">Hello.</div>
--
nohref :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
nohref = attribute "nohref" " nohref=\""
{-# INLINE nohref #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @noshade@ attribute.
--
-- Example:
--
-- > div ! noshade "bar" $ "Hello."
--
-- Result:
--
-- > <div noshade="bar">Hello.</div>
--
noshade :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
noshade = attribute "noshade" " noshade=\""
{-# INLINE noshade #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @nowrap@ attribute.
--
-- Example:
--
-- > div ! nowrap "bar" $ "Hello."
--
-- Result:
--
-- > <div nowrap="bar">Hello.</div>
--
nowrap :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
nowrap = attribute "nowrap" " nowrap=\""
{-# INLINE nowrap #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onabort@ attribute.
--
-- Example:
--
-- > div ! onabort "bar" $ "Hello."
--
-- Result:
--
-- > <div onabort="bar">Hello.</div>
--
onabort :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
onabort = attribute "onabort" " onabort=\""
{-# INLINE onabort #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onblur@ attribute.
--
-- Example:
--
-- > div ! onblur "bar" $ "Hello."
--
-- Result:
--
-- > <div onblur="bar">Hello.</div>
--
onblur :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
onblur = attribute "onblur" " onblur=\""
{-# INLINE onblur #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onchange@ attribute.
--
-- Example:
--
-- > div ! onchange "bar" $ "Hello."
--
-- Result:
--
-- > <div onchange="bar">Hello.</div>
--
onchange :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
onchange = attribute "onchange" " onchange=\""
{-# INLINE onchange #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onclick@ attribute.
--
-- Example:
--
-- > div ! onclick "bar" $ "Hello."
--
-- Result:
--
-- > <div onclick="bar">Hello.</div>
--
onclick :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
onclick = attribute "onclick" " onclick=\""
{-# INLINE onclick #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @ondblclick@ attribute.
--
-- Example:
--
-- > div ! ondblclick "bar" $ "Hello."
--
-- Result:
--
-- > <div ondblclick="bar">Hello.</div>
--
ondblclick :: AttributeValue  -- ^ Attribute value.
           -> Attribute       -- ^ Resulting attribute.
ondblclick = attribute "ondblclick" " ondblclick=\""
{-# INLINE ondblclick #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onfocus@ attribute.
--
-- Example:
--
-- > div ! onfocus "bar" $ "Hello."
--
-- Result:
--
-- > <div onfocus="bar">Hello.</div>
--
onfocus :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
onfocus = attribute "onfocus" " onfocus=\""
{-# INLINE onfocus #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onkeydown@ attribute.
--
-- Example:
--
-- > div ! onkeydown "bar" $ "Hello."
--
-- Result:
--
-- > <div onkeydown="bar">Hello.</div>
--
onkeydown :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
onkeydown = attribute "onkeydown" " onkeydown=\""
{-# INLINE onkeydown #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onkeypress@ attribute.
--
-- Example:
--
-- > div ! onkeypress "bar" $ "Hello."
--
-- Result:
--
-- > <div onkeypress="bar">Hello.</div>
--
onkeypress :: AttributeValue  -- ^ Attribute value.
           -> Attribute       -- ^ Resulting attribute.
onkeypress = attribute "onkeypress" " onkeypress=\""
{-# INLINE onkeypress #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onkeyup@ attribute.
--
-- Example:
--
-- > div ! onkeyup "bar" $ "Hello."
--
-- Result:
--
-- > <div onkeyup="bar">Hello.</div>
--
onkeyup :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
onkeyup = attribute "onkeyup" " onkeyup=\""
{-# INLINE onkeyup #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onload@ attribute.
--
-- Example:
--
-- > div ! onload "bar" $ "Hello."
--
-- Result:
--
-- > <div onload="bar">Hello.</div>
--
onload :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
onload = attribute "onload" " onload=\""
{-# INLINE onload #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onmousedown@ attribute.
--
-- Example:
--
-- > div ! onmousedown "bar" $ "Hello."
--
-- Result:
--
-- > <div onmousedown="bar">Hello.</div>
--
onmousedown :: AttributeValue  -- ^ Attribute value.
            -> Attribute       -- ^ Resulting attribute.
onmousedown = attribute "onmousedown" " onmousedown=\""
{-# INLINE onmousedown #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onmousemove@ attribute.
--
-- Example:
--
-- > div ! onmousemove "bar" $ "Hello."
--
-- Result:
--
-- > <div onmousemove="bar">Hello.</div>
--
onmousemove :: AttributeValue  -- ^ Attribute value.
            -> Attribute       -- ^ Resulting attribute.
onmousemove = attribute "onmousemove" " onmousemove=\""
{-# INLINE onmousemove #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onmouseout@ attribute.
--
-- Example:
--
-- > div ! onmouseout "bar" $ "Hello."
--
-- Result:
--
-- > <div onmouseout="bar">Hello.</div>
--
onmouseout :: AttributeValue  -- ^ Attribute value.
           -> Attribute       -- ^ Resulting attribute.
onmouseout = attribute "onmouseout" " onmouseout=\""
{-# INLINE onmouseout #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onmouseover@ attribute.
--
-- Example:
--
-- > div ! onmouseover "bar" $ "Hello."
--
-- Result:
--
-- > <div onmouseover="bar">Hello.</div>
--
onmouseover :: AttributeValue  -- ^ Attribute value.
            -> Attribute       -- ^ Resulting attribute.
onmouseover = attribute "onmouseover" " onmouseover=\""
{-# INLINE onmouseover #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onmouseup@ attribute.
--
-- Example:
--
-- > div ! onmouseup "bar" $ "Hello."
--
-- Result:
--
-- > <div onmouseup="bar">Hello.</div>
--
onmouseup :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
onmouseup = attribute "onmouseup" " onmouseup=\""
{-# INLINE onmouseup #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onreset@ attribute.
--
-- Example:
--
-- > div ! onreset "bar" $ "Hello."
--
-- Result:
--
-- > <div onreset="bar">Hello.</div>
--
onreset :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
onreset = attribute "onreset" " onreset=\""
{-# INLINE onreset #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onselect@ attribute.
--
-- Example:
--
-- > div ! onselect "bar" $ "Hello."
--
-- Result:
--
-- > <div onselect="bar">Hello.</div>
--
onselect :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
onselect = attribute "onselect" " onselect=\""
{-# INLINE onselect #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onsubmit@ attribute.
--
-- Example:
--
-- > div ! onsubmit "bar" $ "Hello."
--
-- Result:
--
-- > <div onsubmit="bar">Hello.</div>
--
onsubmit :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
onsubmit = attribute "onsubmit" " onsubmit=\""
{-# INLINE onsubmit #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @onunload@ attribute.
--
-- Example:
--
-- > div ! onunload "bar" $ "Hello."
--
-- Result:
--
-- > <div onunload="bar">Hello.</div>
--
onunload :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
onunload = attribute "onunload" " onunload=\""
{-# INLINE onunload #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @profile@ attribute.
--
-- Example:
--
-- > div ! profile "bar" $ "Hello."
--
-- Result:
--
-- > <div profile="bar">Hello.</div>
--
profile :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
profile = attribute "profile" " profile=\""
{-# INLINE profile #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @readonly@ attribute.
--
-- Example:
--
-- > div ! readonly "bar" $ "Hello."
--
-- Result:
--
-- > <div readonly="bar">Hello.</div>
--
readonly :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
readonly = attribute "readonly" " readonly=\""
{-# INLINE readonly #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @rel@ attribute.
--
-- Example:
--
-- > div ! rel "bar" $ "Hello."
--
-- Result:
--
-- > <div rel="bar">Hello.</div>
--
rel :: AttributeValue  -- ^ Attribute value.
    -> Attribute       -- ^ Resulting attribute.
rel = attribute "rel" " rel=\""
{-# INLINE rel #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @rev@ attribute.
--
-- Example:
--
-- > div ! rev "bar" $ "Hello."
--
-- Result:
--
-- > <div rev="bar">Hello.</div>
--
rev :: AttributeValue  -- ^ Attribute value.
    -> Attribute       -- ^ Resulting attribute.
rev = attribute "rev" " rev=\""
{-# INLINE rev #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @rows@ attribute.
--
-- Example:
--
-- > div ! rows "bar" $ "Hello."
--
-- Result:
--
-- > <div rows="bar">Hello.</div>
--
rows :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
rows = attribute "rows" " rows=\""
{-# INLINE rows #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @rowspan@ attribute.
--
-- Example:
--
-- > div ! rowspan "bar" $ "Hello."
--
-- Result:
--
-- > <div rowspan="bar">Hello.</div>
--
rowspan :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
rowspan = attribute "rowspan" " rowspan=\""
{-# INLINE rowspan #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @rules@ attribute.
--
-- Example:
--
-- > div ! rules "bar" $ "Hello."
--
-- Result:
--
-- > <div rules="bar">Hello.</div>
--
rules :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
rules = attribute "rules" " rules=\""
{-# INLINE rules #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @scheme@ attribute.
--
-- Example:
--
-- > div ! scheme "bar" $ "Hello."
--
-- Result:
--
-- > <div scheme="bar">Hello.</div>
--
scheme :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
scheme = attribute "scheme" " scheme=\""
{-# INLINE scheme #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @scope@ attribute.
--
-- Example:
--
-- > div ! scope "bar" $ "Hello."
--
-- Result:
--
-- > <div scope="bar">Hello.</div>
--
scope :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
scope = attribute "scope" " scope=\""
{-# INLINE scope #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @scrolling@ attribute.
--
-- Example:
--
-- > div ! scrolling "bar" $ "Hello."
--
-- Result:
--
-- > <div scrolling="bar">Hello.</div>
--
scrolling :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
scrolling = attribute "scrolling" " scrolling=\""
{-# INLINE scrolling #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @selected@ attribute.
--
-- Example:
--
-- > div ! selected "bar" $ "Hello."
--
-- Result:
--
-- > <div selected="bar">Hello.</div>
--
selected :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
selected = attribute "selected" " selected=\""
{-# INLINE selected #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @shape@ attribute.
--
-- Example:
--
-- > div ! shape "bar" $ "Hello."
--
-- Result:
--
-- > <div shape="bar">Hello.</div>
--
shape :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
shape = attribute "shape" " shape=\""
{-# INLINE shape #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @size@ attribute.
--
-- Example:
--
-- > div ! size "bar" $ "Hello."
--
-- Result:
--
-- > <div size="bar">Hello.</div>
--
size :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
size = attribute "size" " size=\""
{-# INLINE size #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @span@ attribute.
--
-- Example:
--
-- > div ! span "bar" $ "Hello."
--
-- Result:
--
-- > <div span="bar">Hello.</div>
--
span :: AttributeValue  -- ^ Attribute value.
     -> Attribute       -- ^ Resulting attribute.
span = attribute "span" " span=\""
{-# INLINE span #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @src@ attribute.
--
-- Example:
--
-- > div ! src "bar" $ "Hello."
--
-- Result:
--
-- > <div src="bar">Hello.</div>
--
src :: AttributeValue  -- ^ Attribute value.
    -> Attribute       -- ^ Resulting attribute.
src = attribute "src" " src=\""
{-# INLINE src #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @standby@ attribute.
--
-- Example:
--
-- > div ! standby "bar" $ "Hello."
--
-- Result:
--
-- > <div standby="bar">Hello.</div>
--
standby :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
standby = attribute "standby" " standby=\""
{-# INLINE standby #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @start@ attribute.
--
-- Example:
--
-- > div ! start "bar" $ "Hello."
--
-- Result:
--
-- > <div start="bar">Hello.</div>
--
start :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
start = attribute "start" " start=\""
{-# INLINE start #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @style@ attribute.
--
-- Example:
--
-- > div ! style "bar" $ "Hello."
--
-- Result:
--
-- > <div style="bar">Hello.</div>
--
style :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
style = attribute "style" " style=\""
{-# INLINE style #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @summary@ attribute.
--
-- Example:
--
-- > div ! summary "bar" $ "Hello."
--
-- Result:
--
-- > <div summary="bar">Hello.</div>
--
summary :: AttributeValue  -- ^ Attribute value.
        -> Attribute       -- ^ Resulting attribute.
summary = attribute "summary" " summary=\""
{-# INLINE summary #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @tabindex@ attribute.
--
-- Example:
--
-- > div ! tabindex "bar" $ "Hello."
--
-- Result:
--
-- > <div tabindex="bar">Hello.</div>
--
tabindex :: AttributeValue  -- ^ Attribute value.
         -> Attribute       -- ^ Resulting attribute.
tabindex = attribute "tabindex" " tabindex=\""
{-# INLINE tabindex #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @target@ attribute.
--
-- Example:
--
-- > div ! target "bar" $ "Hello."
--
-- Result:
--
-- > <div target="bar">Hello.</div>
--
target :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
target = attribute "target" " target=\""
{-# INLINE target #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @title@ attribute.
--
-- Example:
--
-- > div ! title "bar" $ "Hello."
--
-- Result:
--
-- > <div title="bar">Hello.</div>
--
title :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
title = attribute "title" " title=\""
{-# INLINE title #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @type@ attribute.
--
-- Example:
--
-- > div ! type_ "bar" $ "Hello."
--
-- Result:
--
-- > <div type="bar">Hello.</div>
--
type_ :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
type_ = attribute "type" " type=\""
{-# INLINE type_ #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @usemap@ attribute.
--
-- Example:
--
-- > div ! usemap "bar" $ "Hello."
--
-- Result:
--
-- > <div usemap="bar">Hello.</div>
--
usemap :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
usemap = attribute "usemap" " usemap=\""
{-# INLINE usemap #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @valign@ attribute.
--
-- Example:
--
-- > div ! valign "bar" $ "Hello."
--
-- Result:
--
-- > <div valign="bar">Hello.</div>
--
valign :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
valign = attribute "valign" " valign=\""
{-# INLINE valign #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @value@ attribute.
--
-- Example:
--
-- > div ! value "bar" $ "Hello."
--
-- Result:
--
-- > <div value="bar">Hello.</div>
--
value :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
value = attribute "value" " value=\""
{-# INLINE value #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @valuetype@ attribute.
--
-- Example:
--
-- > div ! valuetype "bar" $ "Hello."
--
-- Result:
--
-- > <div valuetype="bar">Hello.</div>
--
valuetype :: AttributeValue  -- ^ Attribute value.
          -> Attribute       -- ^ Resulting attribute.
valuetype = attribute "valuetype" " valuetype=\""
{-# INLINE valuetype #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @vspace@ attribute.
--
-- Example:
--
-- > div ! vspace "bar" $ "Hello."
--
-- Result:
--
-- > <div vspace="bar">Hello.</div>
--
vspace :: AttributeValue  -- ^ Attribute value.
       -> Attribute       -- ^ Resulting attribute.
vspace = attribute "vspace" " vspace=\""
{-# INLINE vspace #-}

-- WARNING: The next block of code was automatically generated by
-- src/Util/GenerateHtmlCombinators.hs:250
--
-- | Combinator for the @width@ attribute.
--
-- Example:
--
-- > div ! width "bar" $ "Hello."
--
-- Result:
--
-- > <div width="bar">Hello.</div>
--
width :: AttributeValue  -- ^ Attribute value.
      -> Attribute       -- ^ Resulting attribute.
width = attribute "width" " width=\""
{-# INLINE width #-}
